.. _dodelijk:

DODELIJK
########

Antipsychotica zijn levenbedreigend, toedienen brengt de kans op sterven:

| Antipsychotica zijn neurotoxisch, zie https://nl.wikipedia.org/wiki/Neurotoxine.
| Antipsychotica zijn dodelijk, zie :ref:`toxic <toxic>`.
| Antipsychotica zijn dodelijk, zie bijsluiter van bijv. :ref:`clozapine <clozapine>`.

Bijv. clozapine kan de volgende potentieel dodelijk aandoeningen veroorzaken:

| Neutropenia (tekort witte bloedcellen)
| Myocarditis (ontsteking hartspier)
| Cardiomyopathy (ook hartspier)
| Hypotension (lage bloeddruk)
| Bradycardia (trage hartslag)
| Syncope (flauwvallen)
| Cardiac arrest (hartstilstand)
| Neuroleptic Malignant Syndrome (NMS)
| Constipation (dikke darm verstopping)
| Intestinal Obstruction (darm problemen)
| Fecal Impaction (vastzittend stront)
| Paralytic Ileus (ook voedsel vastzittend in de darm)

